# -*- coding: utf-8 -*-
{
    'name': "Partner Autocomplete extends Address autocomplete",
    'summary': "Autocomplete extended addresses",
    'description': """
Correct address formating when both partner_autocomplete and base_address_extended modules are installed""",
    'author': "Odoo SA",
    'category': 'Tools',
    'version': '1.0',
    'depends': ['partner_autocomplete', 'base_address_extended'],
    'auto_install': True,
}
